<?php

namespace FiloBlu\AdyenPaymentLinkGenerator\Helper;

use Magento\Framework\App\Helper\AbstractHelper;
use Magento\Store\Model\ScopeInterface;

class Data extends AbstractHelper
{
    const PAYMENT_LINK_GENERATOR_ENABLED_PATH = 'adyen_payment_link_generator/general/payment_link_generator_enabled';

    const PAYMENT_LINK_GENERATOR_TYPE_DURATION_PATH = 'adyen_payment_link_generator/general/payment_link_generator_type_duration';

    const PAYMENT_LINK_GENERATOR_DAYS_AMOUNT_PATH = 'adyen_payment_link_generator/general/payment_link_generator_days_amount';

    const PAYMENT_LINK_GENERATOR_HOURS_AMOUNT_PATH = 'adyen_payment_link_generator/general/payment_link_generator_hours_amount';

    const PAYMENT_LINK_GENERATOR_HPP_NOT_ALLOWED = 'adyen_payment_link_generator/general/payment_link_generator_hpp_not_allowed';

    const DAYS = 'days';

    const HOURS = 'hours';

    const PAYMENT_METHOD_ALLOW = '/adyen_*/';

    const ORDER_STATUS_NOT_ALLOW_PAYMENT_LINK = array(
        'payment_confirmed',
        'payment_confirmed_on_ext',
        'payment_exported',
        'invoiced',
        'sent_to_logistics',
        'complete',
        'complete_in_store',
        'shipped'
    );


    /**
     * @return bool
     */
    public function paymentLinkGeneratorIsEnabled()
    {
        return $this->scopeConfig->isSetFlag(self::PAYMENT_LINK_GENERATOR_ENABLED_PATH, ScopeInterface::SCOPE_STORE);
    }

    /**
     * @return mixed
     */
    public function paymentLinkGeneratorTypeDuration()
    {
        return $this->scopeConfig->getValue(self::PAYMENT_LINK_GENERATOR_TYPE_DURATION_PATH, ScopeInterface::SCOPE_STORE);
    }

    /**
     * @return mixed
     */
    public function getDaysAmount()
    {
        return $this->scopeConfig->getValue(self::PAYMENT_LINK_GENERATOR_DAYS_AMOUNT_PATH, ScopeInterface::SCOPE_STORE);
    }

    /**
     * @return mixed
     */
    public function getHoursAmount()
    {
        return $this->scopeConfig->getValue(self::PAYMENT_LINK_GENERATOR_HOURS_AMOUNT_PATH, ScopeInterface::SCOPE_STORE);
    }

    /**
     * @return \DateTime
     * @throws \Exception
     */
    public function expireCalculation()
    {
        $now = new \DateTime();

        if($this->paymentLinkGeneratorTypeDuration() == self::DAYS){
            $now->add(new \DateInterval('P'.$this->getDaysAmount().'D'));
        } else {
            $now->add(new \DateInterval('PT'.$this->getHoursAmount().'H'));
        }

        return $now;
    }

    /**
     * @return mixed
     */
    public function getHppNotAllowed()
    {
        return $this->scopeConfig->getValue(self::PAYMENT_LINK_GENERATOR_HPP_NOT_ALLOWED, ScopeInterface::SCOPE_STORE);
    }

    /**
     * @return array|false|string[]
     */
    public function getHppNotAllowedArray()
    {
        $result = [];
        $hppCode = $this->getHppNotAllowed();
        if($hppCode != '')
        {
            $result = explode(',', $hppCode);
        }
        return $result;
    }
}
