<?php

namespace FiloBlu\AdyenPaymentLinkGenerator\Plugin\Magento\Backend\Block\Widget;

use FiloBlu\AdyenPaymentLinkGenerator\Helper\Data;
use Magento\Backend\Block\Widget\Context as WidgetContext;
use Magento\Backend\Block\Widget\Button\ButtonList;
use Magento\Framework\App\Action\Context as ActionContext;
use Magento\Framework\AuthorizationInterface;
use Magento\Framework\Registry;

class Context
{
    /**
     * @var ActionContext
     */
    protected $context;

    /**
     * @var Registry
     */
    protected $coreRegistry;

    /**
     * @var \Magento\Framework\UrlInterface
     */
    protected $urlBuilder;

    /**
     * @var Data
     */
    protected $helper;

    /**
     * @var AuthorizationInterface
     */
    private $authorization;

    public function __construct(
        ActionContext $context,
        Registry $registry,
        Data $helper,
        AuthorizationInterface $authorization
    )
    {
        $this->context = $context;
        $this->coreRegistry = $registry;
        $this->urlBuilder = $context->getUrl();
        $this->helper = $helper;
        $this->authorization = $authorization;
    }

    public function afterGetButtonList(
        WidgetContext $subject,
        ButtonList $buttonList
    )
    {
        $request = $this->context->getRequest();
        if($request->getFullActionName() == 'sales_order_view') {
            $order = $this->getCurrentOrder();
            $paymentMethod = $order->getPayment()->getMethod();
            if($this->helper->paymentLinkGeneratorIsEnabled() &&
                !in_array($order->getStatus(), Data::ORDER_STATUS_NOT_ALLOW_PAYMENT_LINK) &&
                $this->authorization->isAllowed('FiloBlu_AdyenPaymentLinkGenerator::config_filoblu_adyenpaymentlinkgenerator')) {

                $message = __('Do you confirm the Pay by Link creation?');
                $url = $this->urlBuilder->getUrl('filobluadyenpaymentlinkgenerator/Order/Generatelink', ['order_id' => $order->getId()]);
                $buttonList->add(
                    'test',
                    [
                        'label' => __('Generate Pay by Link'),
                        'onclick' => "confirmSetLocation('{$message}', '{$url}')"
                    ]
                );
            }
        }

        return $buttonList;
    }

    /**
     * @return \Magento\Sales\Model\Order|null
     */
    public function getCurrentOrder()
    {
        return $this->coreRegistry->registry('current_order');
    }
}

